# Please keep this package in sync with FC

%define major 1

%define libname %mklibname %{name}-server %{major}
%define libnamedev %mklibname %{name}-server -d

Name:		spice
Version:	0.14.3
Release:	%mkrel 3
Summary:	Implements the SPICE protocol
Group:		Networking/Remote access
License:	LGPLv2+
URL:		http://www.spice-space.org/
Source0:	http://www.spice-space.org/download/releases/spice-server/%{name}-%{version}.tar.bz2
Patch0:		CVE-2020-14355-1.patch
Patch1:		CVE-2020-14355-2.patch
Patch2:		CVE-2020-14355-3.patch
Patch3:		CVE-2020-14355-4.patch
Patch500:	spice-autoconf.patch

# https://bugzilla.redhat.com/show_bug.cgi?id=613529
ExclusiveArch:  %{ix86} x86_64 %{arm} aarch64

BuildRequires: pkgconfig(glib-2.0) >= 2.22
BuildRequires: pkgconfig(libcacard) >= 0.1.2
BuildRequires: pkgconfig(openssl)
BuildRequires: pkgconfig(pixman-1) >= 0.17.7
BuildRequires: pkgconfig(spice-protocol) >= 0.14.0
BuildRequires: pkgconfig(opus) >= 0.9.14
BuildRequires: libjpeg-devel
BuildRequires: pkgconfig(xrandr)
BuildRequires: libsasl-devel
BuildRequires: pkgconfig(gl)
BuildRequires: pkgconfig(glu)
BuildRequires: lz4-devel
BuildRequires: gstreamer1.0-devel gstreamer1.0-plugins-base-devel
BuildRequires: orc-devel
BuildRequires: git-core

%description
The Simple Protocol for Independent Computing Environments (SPICE) is
a remote display system built for virtual environments which allows
you to view a computing 'desktop' environment not only on the machine
where it is running, but from anywhere on the Internet and from a wide
variety of machine architectures.

%package client
Summary:	Implements the client side of the SPICE protocol
Group:		Networking/Remote access
Requires(post):	%{_sbindir}/update-alternatives
Requires(postun):	%{_sbindir}/update-alternatives

%description client
The Simple Protocol for Independent Computing Environments (SPICE) is
a remote display system built for virtual environments which allows
you to view a computing 'desktop' environment not only on the machine
where it is running, but from anywhere on the Internet and from a wide
variety of machine architectures.

This package contains the SPICE client application.

%package -n %libname
Summary:	Implements the server side of the SPICE protocol
Group:		System/Libraries

%description -n %libname
The Simple Protocol for Independent Computing Environments (SPICE) is
a remote display system built for virtual environments which allows
you to view a computing 'desktop' environment not only on the machine
where it is running, but from anywhere on the Internet and from a wide
variety of machine architectures.

This package contains the run-time libraries for any application that wishes
to be a SPICE server.

%package -n %libnamedev
Summary:	Header files, libraries and development documentation for spice-server
Group:		Development/C
Requires:	%libname = %{version}-%{release}
Requires:	pkgconfig
Requires:	pkgconfig(libcacard)
Requires:	pkgconfig(xinerama)
Provides:	%name-server-devel = %version-%release


%description -n %libnamedev
This package contains the header files, static libraries and development
documentation for spice-server. If you like to develop programs
using spice-server, you will need to install spice-server-devel.

%prep
%setup -q
%autopatch -p1

%build
autoreconf -fi
%configure \
	--enable-smartcard \
	--disable-client \
	--disable-static \
	--disable-werror \
	--enable-lz4 \
	--enable-gstreamer=1.0 \
	--disable-celt051
%make_build

%install
%make_install
rm -f %{buildroot}%{_libdir}/libspice-server.la
%__mkdir_p %{buildroot}%{_libexecdir}

%files client
%license COPYING
%doc README CHANGELOG.md

%files -n %libname
%license COPYING
%doc README
%{_libdir}/libspice-server.so.%{major}
%{_libdir}/libspice-server.so.%{major}.*

%files -n %libnamedev
%{_includedir}/spice-server
%{_libdir}/libspice-server.so
%{_libdir}/pkgconfig/spice-server.pc


%changelog
* Sat Oct 31 2020 wally <wally> 0.14.3-3.mga8
+ Revision: 1640930
- fix build with autoconf > 2.69

* Wed Oct 21 2020 ns80 <ns80> 0.14.3-2.mga8
+ Revision: 1637602
- add Ubuntu patches for CVE-2020-14355 (mga#27368)

* Sat Feb 29 2020 tv <tv> 0.14.3-1.mga8
+ Revision: 1552124
- Update to 0.14.3

* Sat Feb 15 2020 umeabot <umeabot> 0.14.2-2.mga8
+ Revision: 1526247
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed May 01 2019 tv <tv> 0.14.2-1.mga7
+ Revision: 1395967
- new release

* Sat Feb 02 2019 luigiwalser <luigiwalser> 0.14.1-3.mga7
+ Revision: 1362614
- rediff patch from ubuntu to fix CVE-2019-3813

* Tue Jan 01 2019 luigiwalser <luigiwalser> 0.14.1-2.mga7
+ Revision: 1347856
- add patches from opensuse to fix CVE-2018-10893

* Thu Aug 23 2018 tv <tv> 0.14.1-1.mga7
+ Revision: 1253553
- New upstream release
- Disable celt 0.5.1 support, Opus support has been there for 4 years, so
  celt should no longer be needed
- remove uneeded BRs on 2 python modules
  (they're only needed when building from git)
+ kekepower <kekepower>
- Use new make macros

* Wed Oct 11 2017 tv <tv> 0.14.0-1.mga7
+ Revision: 1170942
- new release

* Wed Sep 27 2017 tv <tv> 0.13.91-1.mga7
+ Revision: 1160137
- new release

* Tue Sep 05 2017 tv <tv> 0.13.90-3.mga7
+ Revision: 1151322
- add BRs & enable new features

* Thu Aug 03 2017 tv <tv> 0.13.90-2.mga7
+ Revision: 1134284
- rebuild for new OpenSSL

* Sun Jul 30 2017 luigiwalser <luigiwalser> 0.13.90-1.mga7
+ Revision: 1132622
- 0.13.90 (fixes CVE-2017-7506)
- remove upstream patches

* Thu Feb 16 2017 ns80 <ns80> 0.13.3-3.mga6
+ Revision: 1086444
- add upstream patches for CVE-2016-9577 and CVE-2016-9578 (mga#20251)

* Thu Dec 22 2016 tv <tv> 0.13.3-2.mga6
+ Revision: 1076480
- stop building spicec, it's obsolete and superseded by remote-viewer
  (part of virt-viewer)

* Tue Dec 06 2016 tv <tv> 0.13.3-1.mga6
+ Revision: 1072750
- drop merged patches
- new release

* Thu Sep 29 2016 pterjan <pterjan> 0.12.8-1.mga6
+ Revision: 1057511
- Actually, no need for a patch
- Prevent configure from enabling Werror despite using git for patches
- Update to 0.12.8 which only adds some patches we already add + 2 small fixes

* Tue Jul 19 2016 neoclust <neoclust> 0.12.7-4.mga6
+ Revision: 1042589
- Rebuild for armv7

* Wed Jul 06 2016 luigiwalser <luigiwalser> 0.12.7-3.mga6
+ Revision: 1039171
- add patches from redhat to fix CVE-2016-0749 and CVE-2016-2150
+ tv <tv>
- use %%license

* Mon Apr 25 2016 tv <tv> 0.12.7-2.mga6
+ Revision: 1006119
- call autoreconf b/c of patches

* Sat Apr 23 2016 tv <tv> 0.12.7-1.mga6
+ Revision: 1005461
- sync patches with FC (virgil support, ...)

* Thu Mar 03 2016 umeabot <umeabot> 0.12.6-3.mga6
+ Revision: 984124
- Rebuild for openssl

* Wed Jan 06 2016 blino <blino> 0.12.6-2.mga6
+ Revision: 919933
- enable build on ARM

* Wed Nov 25 2015 fwang <fwang> 0.12.6-1.mga6
+ Revision: 905914
- update file list
- add more br
- foce libmajor
- update br
- 0.12.6

* Wed Oct 07 2015 luigiwalser <luigiwalser> 0.12.5-4.mga6
+ Revision: 886927
- add patches from ubuntu to fix CVE-2015-5260 and CVE-2015-5261

* Fri Sep 04 2015 luigiwalser <luigiwalser> 0.12.5-3.mga6
+ Revision: 872767
- add patch from redhat to fix CVE-2015-3247

* Wed Oct 15 2014 umeabot <umeabot> 0.12.5-2.mga5
+ Revision: 740791
- Second Mageia 5 Mass Rebuild

* Sat Jun 28 2014 pterjan <pterjan> 0.12.5-1.mga5
+ Revision: 640760
- Drop patch
- 0.12.5

* Fri Jan 10 2014 luigiwalser <luigiwalser> 0.12.4-4.mga4
+ Revision: 566180
- add upstream patch to fix CVE-2013-4282

* Sat Aug 31 2013 fwang <fwang> 0.12.4-3.mga4
+ Revision: 473660
- rebuild for new sasl

* Tue Aug 27 2013 luigiwalser <luigiwalser> 0.12.4-2.mga4
+ Revision: 472090
- rebuild for cyrus-sasl

* Sun Jul 21 2013 fwang <fwang> 0.12.4-1.mga4
+ Revision: 456778
- cleanup spec
- autoreconf is not required
- new version 0.12.4

* Sun May 26 2013 ovitters <ovitters> 0.12.3-1.mga4
+ Revision: 428117
- drop merged patch
- new version 0.12.3

* Mon Jan 14 2013 umeabot <umeabot> 0.12.2-5.mga3
+ Revision: 382520
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 30 2012 cjw <cjw> 0.12.2-4.mga3
+ Revision: 336347
- patch2: fix build with automake 1.13
  o use the packaged spice-protocol instead of the bundled version

* Tue Dec 25 2012 cjw <cjw> 0.12.2-3.mga3
+ Revision: 334948
- also add pkgconfig(xinerama) dep to -devel pkg to fix pkgconfig(spice-server)

* Tue Dec 25 2012 cjw <cjw> 0.12.2-2.mga3
+ Revision: 334943
- add dependency on pkgconfig(libcacard) to -devel package to fix pkgconfig(spice-server)

* Tue Dec 25 2012 cjw <cjw> 0.12.2-1.mga3
+ Revision: 334859
- 0.12.2
- patch1: fix linkage

* Tue Feb 28 2012 ovitters <ovitters> 0.10.1-1.mga2
+ Revision: 215751
- new version 0.10.1

* Wed Jan 11 2012 ovitters <ovitters> 0.10.0-2.mga2
+ Revision: 194920
- also build for i586

* Wed Jan 11 2012 ovitters <ovitters> 0.10.0-1.mga2
+ Revision: 194838
- fix group
- fix buildrequires
- fix group
- clean spec file
- imported package spice

